# ManagersEq


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from core.v2.models.managers_eq import ManagersEq

# TODO update the JSON string below
json = "{}"
# create an instance of ManagersEq from a JSON string
managers_eq_instance = ManagersEq.from_json(json)
# print the JSON string representation of the object
print(ManagersEq.to_json())

# convert the object into a dict
managers_eq_dict = managers_eq_instance.to_dict()
# create an instance of ManagersEq from a dict
managers_eq_from_dict = ManagersEq.from_dict(managers_eq_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


